type StringableKey<T> = T extends readonly unknown[] ? number extends T["length"] ? number : `${number}` : string | number;
type Path<T> = T extends object ? {
    [P in keyof T & StringableKey<T>]: `${P}` | `${P}.${Path<T[P]>}`;
}[keyof T & StringableKey<T>] : never;
type UntypedConfig = Record<string, any>;
declare class TeenyConf<Config extends UntypedConfig, ConfigKey extends string = Path<Config>> {
    _configPath: string;
    _defaultConfig: Config;
    _conf: Config;
    constructor(configPath: string, defaultConfig: Config);
    /**
     * Reload the configuration from file
     */
    reload(): void;
    /**
     * Save current config to its associated file
     */
    save(minify?: boolean): void;
    /**
     * Get a key from conf
     */
    get(): Config | undefined;
    get<T extends ConfigKey>(key: T): Config[T] | undefined;
    get<T extends ConfigKey>(key: T, def: Config[T]): Config[T] | undefined;
    /**
     * Set/add key/value pair
     */
    set<T extends ConfigKey>(key: T, value: Config[T]): void;
    /**
     * Delete a key from the configuration
     */
    delete(key: string): void;
    /**
     * Clear the configuration and rolls it back the default config
     */
    clear(): void;
    /**
     * Check if a key exists
     */
    has(key: ConfigKey | string): boolean;
}
export default TeenyConf;
